@@ -7,21 +7,21 @@ cloudflare(thedict=None,debug=False,print=True,downtests=None,uptests=None,laten
 
 thedict: dictionary to store results in
     if not passed in, created here
-    if passed in, used and update - allows keeping partial resutls from previous runs
-    each result has a key and the netry is a dict with "time" and "value" items
+    if passed in, used and update - allows keeping partial results from previous runs
+    each result has a key and the entry is a dict with "time" and "value" items
 debug: True turns on io logging for debugging
 printit: if true, results are printed as well as added to the dictionary
 downtests: tuple of download tests to be performed
     if None, defaultdowntests (see below) is used
     format is ((size, reps, label)......)
         size: size of block to download
-        reps: numer of times to repeat test
+        reps: number of times to repeat test
         label: text label for test - also becomes key in the dict
-uptests: tuple of download tests to be performed
+uptests: tuple of upload tests to be performed
     if None, defaultuptests (see below) is used
     format is ((size, reps, label)......)
-        size: size of block to upnload
-        reps: numer of times to repeat test
+        size: size of block to upload
+        reps: number of times to repeat test
         label: text label for test - also becomes key in the dict
 latencyreps: number of repetitions for latency test
 
@@ -29,11 +29,11 @@ latencyreps: number of repetitions for latency test
 """
 
 class cloudflare:
-    #tests chnaged 1/1/22 to mirror those done by web-based test
+    #tests changed 1/1/22 to mirror those done by web-based test
     uploadtests=((101000,8,'100kB'),(1001000, 6,'1MB'),(10001000, 4,'10MB'))
     downloadtests=((101000, 10,'100kB'),(1001000, 8,'1MB'),(10001000, 6,'10MB'),(25001000, 4,'25MB'))
-    version=1.5
-    def __init__(self,thedict=None,debug=False,printit=True,downtests=None,uptests=None,latencyreps=20,timeout=(3.05,5)):
+    version="1.7.0"
+    def __init__(self,thedict=None,debug=False,printit=True,downtests=None,uptests=None,latencyreps=20,timeout=(3.05,25)):
 
         import requests
         
@@ -97,22 +97,31 @@ class cloudflare:
 
     def download(self,numbytes,iterations):
         #runs download tests
+        import os
+        from contextlib import nullcontext
         import time
+        if os.name == 'nt':
+            import wres
         fulltimes=() #list for all successful times
         servertimes=() #times reported by server
         requesttimes=() #rough proxy for ttfb
-        for i in range(iterations):
-            start=time.time()
-            err=False
-            try: 
-                r=self.mequests.get('http://speed.cloudflare.com/__down?bytes='+str(numbytes),timeout=self.timeout)
-                end=time.time()
-            except:
-                err=True
-            if not err:
-                fulltimes=fulltimes+(end-start,)
-                servertimes=servertimes+(float(r.headers['Server-Timing'].split('=')[1])/1e3,)
-                requesttimes=requesttimes+(r.elapsed.seconds+r.elapsed.microseconds/1e6,)
+        if os.name == 'nt':
+            cm = wres.set_resolution()
+        else:
+            cm = nullcontext()
+        with cm:
+            for i in range(iterations):
+                start=time.time()
+                err=False
+                try: 
+                    r=self.mequests.get('http://speed.cloudflare.com/__down?bytes='+str(numbytes),timeout=self.timeout)
+                    end=time.time()
+                except:
+                    err=True
+                if not err:
+                    fulltimes=fulltimes+(end-start,)
+                    servertimes=servertimes+(float(r.headers['Server-Timing'].split('=')[1])/1e3,)
+                    requesttimes=requesttimes+(r.elapsed.seconds+r.elapsed.microseconds/1e6,)
         return (fulltimes,servertimes,requesttimes)
 
     def upload(self,numbytes,iterations):
@@ -130,7 +139,7 @@ class cloudflare:
         return (servertimes)
 
     def sprint(self,label,value):
-        "time stamps entry and adds to dictionary replacing speces with underscores in key and optionall prints"
+        "time stamps entry and adds to dictionary replacing spaces with underscores in key and optionally prints"
         import time
         if self.printit:
             print(label+":",value)
@@ -178,7 +187,3 @@ class cloudflare:
         
         self.sprint('90th percentile upload speed',round(np.percentile(alltests,90),2))
         return(self.thedict)
-
-
-
-    
